### calculate_geodetic_area

Compute the geodesic area of a polygon.

- Tool: `calculate_geodetic_area`

Parameters

- geometry (string, WKT polygon)
- ellps (string, default "WGS84")

Returns

- area (number), ellps; status, message
